@@ -32,8 +32,6 @@ static std::vector<UserConfigParam*> all_params;
 #include "config/user_config.hpp"
 
 #include "config/stk_config.hpp"
-#include "io/file_manager.hpp"
-#include "io/utf_writer.hpp"
 #include "io/xml_node.hpp"
 #include "race/race_manager.hpp"
 #include "utils/file_utils.hpp"
@@ -652,6 +650,7 @@ std::string UserConfigParams::m_default_kart = "tux";
 
 int UserConfigParams::m_width = 1024;
 int UserConfigParams::m_height = 768;
+int UserConfigParams::m_display_adapter = 0;
 
 bool UserConfigParams::m_texture_compression = true;
 int UserConfigParams::m_high_definition_textures = 1;
