@@ -61,7 +61,6 @@ namespace irr
     namespace scene { class ISceneManager; class IMesh; class IAnimatedMeshSceneNode; class IAnimatedMesh;
         class IMeshSceneNode; class IParticleSystemSceneNode; class ICameraSceneNode; class ILightSceneNode;
         class CLensFlareSceneNode; }
-    namespace gui   { class IGUIEnvironment; class IGUIFont; }
 }
 using namespace irr;
 
@@ -82,84 +81,57 @@ struct SHCoefficients;
   *  ways to manage the 3D scene
   * \ingroup graphics
   */
-class IrrDriver : public IEventReceiver, public NoCopy
+class IrrDriver : public NoCopy
 {    
 private:
     /** The irrlicht device. */
     IrrlichtDevice             *m_device;
     /** Irrlicht scene manager. */
     scene::ISceneManager       *m_scene_manager;
-    /** Irrlicht gui environment. */
-    gui::IGUIEnvironment       *m_gui_env;
     /** Irrlicht video driver. */
     video::IVideoDriver        *m_video_driver;
-    /** Irrlicht race font. */
-    gui::IGUIFont              *m_race_font;
+#ifndef SERVER_ONLY
     /** Renderer. */
     ShaderBasedRenderer        *m_renderer;
     
     /** Wind. */
     Wind                 *m_wind;
-
-    core::dimension2du m_actual_screen_size;
-
     /** The main MRT setup. */
     core::array<video::IRenderTarget> m_mrt;
+#endif
 
     /** Matrixes used in several places stored here to avoid recomputation. */
     core::matrix4 m_ViewMatrix, m_InvViewMatrix, m_ProjMatrix, m_InvProjMatrix, m_ProjViewMatrix, m_InvProjViewMatrix;
 
 public:
-    /** A simple class to store video resolutions. */
-    class VideoMode
-    {
-    private:
-        int m_width;
-        int m_height;
-    public:
-        VideoMode(int w, int h) {m_width=w; m_height=h; }
-        int getWidth() const  {return m_width;  }
-        int getHeight() const {return m_height; }
-    };   // VideoMode
-
+#ifndef SERVER_ONLY
     struct BloomData {
         scene::ISceneNode * node;
         float power;
     };
 
     video::SColorf getAmbientLight() const;
-
+#endif
 
 
 private:
-    std::vector<VideoMode> m_modes;
-
     void                  setupViewports();
 
-    /** Whether the mouse cursor is currently shown */
-    bool                  m_pointer_shown;
-
     /** Store if the scene is complex (based on polycount, etc) */
     int                  m_scene_complexity;
 
+#ifndef SERVER_ONLY
     /** Internal method that applies the resolution in user settings. */
-    void                 applyResolutionSettings();
-    void                 createListOfVideoModes();
-
-    bool                 m_request_screenshot;
-
     bool                 m_ssaoviz;
     bool                 m_shadowviz;
     bool                 m_lightviz;
     bool                 m_boundingboxesviz;
-    bool                 m_recording;
     bool                 m_render_nw_debug;
 
     /** Background colour to reset a buffer. Can be changed by each track. */
     irr::video::SColor m_clear_color;
 
 
-    unsigned             m_last_light_bucket_distance;
     unsigned             m_skinning_joint;
 
     SP::SPDynamicDrawCall* m_sun_interposer;
@@ -176,33 +148,31 @@ private:
     float m_ssao_radius;
     float m_ssao_k;
     float m_ssao_sigma;
+#endif
     
 #ifdef DEBUG
     /** Used to visualise skeletons. */
     std::vector<irr::scene::IAnimatedMeshSceneNode*> m_debug_meshes;
 #endif
 
-public:
-    void doScreenShot();    
 public:
          IrrDriver();
         ~IrrDriver();
     void initDevice();
     void reset();
+
+#ifndef SERVER_ONLY
     void setMaxTextureSize();
     void unsetMaxTextureSize();
     void getOpenGLData(std::string *vendor, std::string *renderer,
                        std::string *version);
 
-    void increaseObjectCount();
     core::array<video::IRenderTarget> &getMainSetup();
-    void updateConfigIfRelevant();
-    core::recti getSplitscreenWindow(int WindowNum);
+#endif
     void setAllMaterialFlags(scene::IMesh *mesh) const;
     scene::IAnimatedMesh *getAnimatedMesh(const std::string &name);
     scene::IMesh         *getMesh(const std::string &name);
-    void displayFPS();
-    bool                  OnEvent(const irr::SEvent &event);
+#ifndef SERVER_ONLY
     void                  setAmbientLight(const video::SColorf &light,
                                           bool force_SH_computation = true);
     video::ITexture      *getTexture(FileManager::AssetType type,
@@ -218,24 +188,17 @@ public:
     void                  dropAllTextures(const scene::IMesh *mesh);
     scene::IMesh         *createQuadMesh(const video::SMaterial *material=NULL,
                                          bool create_one_quad=false);
-    scene::IMesh         *createTexturedQuadMesh(const video::SMaterial *material,
-                                                 const double w, const double h);
-    scene::ISceneNode    *addWaterNode(scene::IMesh *mesh, scene::IMesh **welded,
-                                       float wave_height,
-                                       float wave_speed, float wave_length);
-    scene::IMeshSceneNode*addOctTree(scene::IMesh *mesh);
     scene::ISceneNode* addSphere(float radius,
                  const video::SColor &color=video::SColor(128, 255, 255, 255));
+#endif
     scene::ISceneNode* addMesh(scene::IMesh *mesh,
                                const std::string& debug_name,
                                scene::ISceneNode *parent = NULL,
                                std::shared_ptr<RenderInfo> render_info = nullptr);
-    PerCameraNode        *addPerCameraNode(scene::ISceneNode* node,
-                                           scene::ICameraSceneNode* cam,
-                                           scene::ISceneNode *parent = NULL);
     scene::ISceneNode    *addBillboard(const core::dimension2d< f32 > size,
                                        const std::string& tex_name,
                                        scene::ISceneNode* parent=NULL);
+#ifndef SERVER_ONLY
     scene::IParticleSystemSceneNode
                          *addParticleNode(bool default_emitter=true);
     scene::ISceneNode    *addSkyDome(video::ITexture *texture, int hori_res,
@@ -244,6 +207,7 @@ public:
     scene::ISceneNode    *addSkyBox(const std::vector<video::ITexture*> &texture_names,
                                     const std::vector<video::ITexture*> &spherical_harmonics_textures);
     void suppressSkyBox();
+#endif
     void                  removeNode(scene::ISceneNode *node);
     void                  removeMeshFromCache(scene::IMesh *mesh);
     void                  removeTexture(video::ITexture *t);
@@ -254,29 +218,18 @@ public:
                          std::shared_ptr<RenderInfo> render_info = nullptr);
     scene::ICameraSceneNode
                          *addCameraSceneNode();
-    Camera               *addCamera(unsigned int index, AbstractKart *kart);
     void                  removeCameraSceneNode(scene::ICameraSceneNode *camera);
-    void                  removeCamera(Camera *camera);
     void                  minimalUpdate(float dt);
 
-    bool                  moveWindow(int x, int y);
-
-    void                  showPointer();
-    void                  hidePointer();
-    void                  setLastLightBucketDistance(unsigned d) { m_last_light_bucket_distance = d; }
+#ifndef SERVER_ONLY
     void                  setSkinningJoint(unsigned d) { m_skinning_joint = d; }
-    bool                  isPointerShown() const { return m_pointer_shown; }
-    core::position2di     getMouseLocation();
+#endif
 
-    void                  printRenderStats();
-    void                  requestScreenshot();
     class GPUTimer        &getGPUTimer(unsigned);
-    const char*           getGPUQueryPhaseName(unsigned);
 
 #ifndef SERVER_ONLY
     std::unique_ptr<RenderTarget> createRenderTarget(const irr::core::dimension2du &dimension,
                                                      const std::string &name);
-#endif
     // ------------------------------------------------------------------------
     /** Returns the color to clear the back buffer. */
     const irr::video::SColor& getClearColor() const { return m_clear_color; }
@@ -286,14 +239,8 @@ public:
     {
         m_clear_color = color;
     }   // setClearbackBufferColor
+#endif
 
-
-    /** Returns a list of all video modes supports by the graphics card. */
-    const std::vector<VideoMode>& getVideoModes() const { return m_modes; }
-    // ------------------------------------------------------------------------
-    /** Returns the frame size. */
-    const core::dimension2d<u32>& getFrameSize() const
-                       { return m_video_driver->getCurrentRenderTargetSize(); }
     // ------------------------------------------------------------------------
     /** Returns the irrlicht device. */
     IrrlichtDevice       *getDevice()       const { return m_device;        }
@@ -304,21 +251,20 @@ public:
     /** Returns the irrlicht scene manager. */
     scene::ISceneManager *getSceneManager() const { return m_scene_manager; }
     // ------------------------------------------------------------------------
-    /** Returns the gui environment, used to add widgets to a screen. */
-    gui::IGUIEnvironment *getGUI() const { return m_gui_env; }
-    // ------------------------------------------------------------------------
     /** Returns the current real time, which might not be 0 at start of the
      *  application. Value in msec. */
-    unsigned int getRealTime() {return m_device->getTimer()->getRealTime(); }
+    unsigned int getRealTime() { return m_device->getTimer()->getRealTime(); }
     // ------------------------------------------------------------------------
     /** Use motion blur for a short time */
-    void giveBoost(unsigned int cam_index) { m_renderer->giveBoost(cam_index);}
+    void giveBoost(unsigned int cam_index) {
+#ifndef SERVER_ONLY
+        m_renderer->giveBoost(cam_index);
+#endif
+    }
+#ifndef SERVER_ONLY
     // ------------------------------------------------------------------------
     inline core::vector3df getWind()  {return m_wind->getWind();}
 
-    // -----------------------------------------------------------------------
-    /** Returns a pointer to the spherical harmonics coefficients. */
-    inline const SHCoefficients* getSHCoefficients()  {return m_renderer->getSHCoefficients();}
     // -----------------------------------------------------------------------
     const core::vector3df& getSunDirection() const { return m_sun_direction; };
     // -----------------------------------------------------------------------
@@ -334,28 +280,8 @@ public:
         m_suncolor = col;
     }
     // ------------------------------------------------------------------------
-    GLuint getRenderTargetTexture(TypeRTT which);
-    GLuint getDepthStencilTexture();
-    // ------------------------------------------------------------------------
-    void resetDebugModes();
-    // ------------------------------------------------------------------------
-    void toggleSSAOViz()          { m_ssaoviz = !m_ssaoviz;         }
-    // ------------------------------------------------------------------------
-    bool getSSAOViz()             { return m_ssaoviz;               }
-    // ------------------------------------------------------------------------
-    void toggleShadowViz()        { m_shadowviz = !m_shadowviz;     }
-    // ------------------------------------------------------------------------
-    bool getShadowViz()           { return m_shadowviz;             }
-    // ------------------------------------------------------------------------
-    void toggleBoundingBoxesViz() { m_boundingboxesviz = !m_boundingboxesviz; }
-    // ------------------------------------------------------------------------
-    void toggleRenderNetworkDebug() { m_render_nw_debug = !m_render_nw_debug; }
-    // ------------------------------------------------------------------------
-    bool getRenderNetworkDebug() const            { return m_render_nw_debug; }
-    // ------------------------------------------------------------------------
-    void renderNetworkDebug();
-    // ------------------------------------------------------------------------
     bool getBoundingBoxesViz()    { return m_boundingboxesviz;      }
+#endif
     // ------------------------------------------------------------------------
     int getSceneComplexity() { return m_scene_complexity;           }
     void resetSceneComplexity() { m_scene_complexity = 0;           }
@@ -363,21 +289,10 @@ public:
     {
         if (complexity > 1) m_scene_complexity += (complexity - 1);
     }
-    // ------------------------------------------------------------------------
-    bool isRecording() const { return m_recording; }
-    // ------------------------------------------------------------------------
-    void setRecording(bool val);
+#ifndef SERVER_ONLY
     // ------------------------------------------------------------------------
     std::vector<LightNode *> getLights() { return m_lights; }
     // ------------------------------------------------------------------------
-    void addGlowingNode(scene::ISceneNode *n, float r = 1.0f, float g = 1.0f,
-                        float b = 1.0f)
-    {
-        m_renderer->addGlowingNode(n, r, g, b);
-    }
-    // ------------------------------------------------------------------------
-    void clearGlowingNodes() { m_renderer->clearGlowingNodes(); }
-    // ------------------------------------------------------------------------
     void addForcedBloomNode(scene::ISceneNode *n, float power = 1)
     {
         BloomData dat;
@@ -413,6 +328,7 @@ public:
     
     void cleanSunInterposer();
     void createSunInterposer();
+#endif
     // ------------------------------------------------------------------------
     void setViewMatrix(core::matrix4 matrix)
     {
@@ -445,15 +361,17 @@ public:
     {
         return m_InvProjViewMatrix;
     }
+
+#ifndef SERVER_ONLY
     // ------------------------------------------------------------------------
-    const core::vector2df &getCurrentScreenSize() const
+    const core::dimension2du &getCurrentScreenSize() const
     {
         return m_renderer->getCurrentScreenSize();
     }
     // ------------------------------------------------------------------------
     const core::dimension2du getActualScreenSize() const
-    { 
-        return m_actual_screen_size;
+    {
+        return getCurrentScreenSize();
     }
     // ------------------------------------------------------------------------
     float getSSAORadius() const
@@ -490,31 +408,16 @@ public:
     {
         m_ssao_sigma = v;
     }
-#ifdef DEBUG
-    std::vector<scene::IAnimatedMeshSceneNode*> getDebugMeshes()
-    {
-        return m_debug_meshes;
-    }
-    /** Removes debug meshes. */
-    void clearDebugMesh() { m_debug_meshes.clear(); }
-    // ------------------------------------------------------------------------
-    /** Adds a debug mesh to be displaed. */
-    void addDebugMesh(scene::IAnimatedMeshSceneNode *node)
-    {
-        m_debug_meshes.push_back(node);
-    }   // addDebugMesh
-
-#endif
+#endif  // SERVER_ONLY
     void onLoadWorld();
     void onUnloadWorld();
-
-    void updateSplitAndLightcoordRangeFromComputeShaders(size_t width,
-                                                         size_t height);
-
-    void uploadLightingData();
     void sameRestart()             {}
+
+#ifndef SERVER_ONLY
+    void uploadLightingData();
     u32 getDefaultFramebuffer() const
                             { return m_video_driver->getDefaultFramebuffer(); }
+#endif  // SERVER_ONLY
 };   // IrrDriver
 
 extern IrrDriver *irr_driver;
